@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-from .pysql import *
+from .droidsql import *
  
-__version__ = '1.0.2'
+__version__ = '1.0.3'
 __license__ = ''
\ No newline at end of file
